@@ -19,6 +19,8 @@
 #' @param lon numeric; degrees east for the meridians
 #' @param lat numeric; degrees north for the parallels
 #' @param ndiscr integer; number of points to discretize a parallel or meridian
+#' @param margin numeric; small number to trim a longlat bounding box that touches or 
+#'  crosses +/-180 long or +/-90 latitude.
 #' @param ... ignored
 #' @return an object of class \code{sf} with additional attributes describing the type 
 #' (E: meridian, N: parallel) degree value, label, start and end coordinates and angle;
@@ -58,7 +60,8 @@
 #' }))
 #' plot(usa, graticule = st_crs(4326), axes = TRUE, lon = seq(-60,-130,by=-10))
 st_graticule = function(x = c(-180,-90,180,90), crs = st_crs(x), 
-	datum = st_crs(4326), ..., lon = NULL, lat = NULL, ndiscr = 100)
+	datum = st_crs(4326), ..., lon = NULL, lat = NULL, ndiscr = 100,
+	margin = 0.001)
 {
 	if (missing(x)) {
 		crs = datum
@@ -75,25 +78,43 @@ st_graticule = function(x = c(-180,-90,180,90), crs = st_crs(x),
 		x
 	stopifnot(is.numeric(bb) && length(bb) == 4)
 
-	ls = st_linestring(rbind(c(bb[1],bb[2]), c(bb[3],bb[2]), c(bb[3],bb[4]), 
-		c(bb[1],bb[4]), c(bb[1],bb[2])))
-	box = st_sfc(ls, crs = crs)
+	if (st_is_longlat(crs))
+		bb = trim_bb(bb, margin)
 
-	box = st_segmentize(box, st_length(ls) / 400, warn = FALSE)
+	ls1 = st_linestring(rbind(c(bb[1],bb[2]), c(bb[3],bb[2]), c(bb[3],bb[4]), 
+		c(bb[1],bb[4]), c(bb[1],bb[2])))
+	ls2 = st_linestring(rbind(c(bb[1],bb[2]), c(bb[3],bb[4]), c(bb[1],bb[4]), 
+		c(bb[3],bb[2]), c(bb[1],bb[2])))
+	box = st_sfc(ls1, ls2, crs = crs)
+
+	box = st_segmentize(box, st_length(ls1) / 400, warn = FALSE)
 
 	# Now we're moving to long/lat:
 	if (!is.na(crs))
 		box = st_transform(box, datum)
+	
+	# as in https://github.com/edzer/sfr/issues/198 : 
+	# recreate, and ignore bbox:
+	if (any(!is.finite(st_bbox(box)))) {
+		x = st_transform(st_graticule(datum = datum), crs)
+		x$degree_label = NA_character_
+		return(x)
+	}
 
-	if (is.null(lon))
-		lon = pretty(st_bbox(box)[c(1,3)])
+	bb = st_bbox(box)
+	if (is.null(lon)) {
+		lon = if (bb[1] < -170 && bb[3] > 170) # "global"
+				seq(-180, 180, by = 60)
+			else
+				pretty(bb[c(1,3)], n = 6)
+	}
 	if (is.null(lat))
-		lat = pretty(st_bbox(box)[c(2,4)])
+		lat = pretty(bb[c(2,4)], n = 6)
+
 	# sanity:
 	lon = lon[lon >= -180 & lon <= 180]
 	lat = lat[lat > -90 & lat < 90]
 
-	bb = st_bbox(box)
 	# widen bb if pretty() created values outside the box:
 	bb = c(min(bb[1], min(lon)), min(bb[2],min(lat)), max(bb[3], max(lon)), max(bb[4], max(lat)))
 
@@ -121,7 +142,7 @@ st_graticule = function(x = c(-180,-90,180,90), crs = st_crs(x),
 	if (!missing(x)) { # cut out box:
 		if (! is.na(crs))
 			box = st_transform(box, crs)
-		df = st_intersection(df, st_polygonize(box))
+		df = st_intersection(df, st_polygonize(box[1]))
 	}
 	graticule_attributes(st_cast(df, "MULTILINESTRING"))
 }
@@ -144,6 +165,20 @@ graticule_attributes = function(df) {
 	df
 }
 
+trim_bb = function(bb = c(-180, -90, 180, 90), margin) {
+	stopifnot(margin > 0 && margin <= 1.0)
+	fr = 1.0 - margin
+	if (bb[1] < -180 * fr)
+		bb[1] = -180 * fr
+	if (bb[3] > 180 * fr)
+		bb[3] = 180 * fr
+	if (bb[2] < -90 * fr)
+		bb[2] = -90 * fr
+	if (bb[4] > 90 * fr)
+		bb[4] = 90 * fr
+	bb
+}
+
 # copied from sp:
 degreeLabelsNS = function(x) {
 	pos = sign(x) + 2
