@@ -57,7 +57,7 @@ st_cast(x, "POINT")
 sf = st_sf(a = 3:2, geom = x)
 st_cast(sf, "POINT")
 
-library(dplyr)
+suppressPackageStartupMessages( library(dplyr) )
 
 x %>% st_cast("POINT")
 
@@ -120,3 +120,28 @@ st_bbox(sf1)
 bb = st_bbox(nc)
 bb
 st_crs(bb)
+
+# merge:
+a = data.frame(a = 1:3, b = 5:7)
+st_geometry(a) = st_sfc(st_point(c(0,0)), st_point(c(1,1)), st_point(c(2,2)))
+b = data.frame(x = c("a", "b", "c"), b = c(2,5,6))
+merge(a, b)
+merge(a, b, all = TRUE)
+
+# joins:
+inner_join(a, b)
+left_join(a, b)
+right_join(a, b)
+full_join(a, b)
+semi_join(a, b)
+anti_join(a, b)
+
+# st_joins:
+a = st_sf(a = 1:3,
+ geom = st_sfc(st_point(c(1,1)), st_point(c(2,2)), st_point(c(3,3))))
+b = st_sf(a = 11:14,
+ geom = st_sfc(st_point(c(10,10)), st_point(c(2,2)), st_point(c(2,2)), st_point(c(3,3))))
+st_join(a, b)
+st_join(a, b, left = FALSE)
+st_join(a, b, FUN = mean)
+st_join(a, b, FUN = mean, left = FALSE)
